# Release Manager

A Release Manager for Embedded Apps in your website, such as an SPA.

## Docs

Docs can be found here [docs/index.md](https://github.com/renderbox/django-release-manager/blob/main/docs/index.md) file.

## Status

[![Python Test](https://github.com/renderbox/django-release-manager/actions/workflows/python-test.yml/badge.svg)](https://github.com/renderbox/django-release-manager/actions/workflows/python-test.yml)

[![Generate Docs](https://github.com/renderbox/django-release-manager/actions/workflows/docs.yml/badge.svg)](https://github.com/renderbox/django-release-manager/actions/workflows/docs.yml)

[![Upload Python Package](https://github.com/renderbox/django-release-manager/actions/workflows/python-publish.yml/badge.svg)](https://github.com/renderbox/django-release-manager/actions/workflows/python-publish.yml)
